JsDoc Reference - dom

Generated by JsDoc Toolkit 2.4.0 on Wed Dec 15 2010 21:56:33 GMT-0000 (GMT)
HTML template: Codeview

# Namespace dom

Common and useful DOM elements for the class instance
Defined in: FixedColumns.js.

Namespace Summary
Constructor Attributes | Constructor Name and Description
--- | ---
| dom

Field Summary
Field Attributes | Field Name and Description
--- | ---
<static> | dom.body DataTables body table
<static> | dom.footer DataTables footer table
<static> | dom.header DataTables header table
<static> | dom.scroller DataTables scrolling element

Namespace Detail
dom
Field Detail
<static> {node} dom.body
DataTables body table

Default Value:
  null

<static> {node} dom.footer
DataTables footer table

Default Value:
  null

<static> {node} dom.header
DataTables header table

Default Value:
  null

<static> {node} dom.scroller
DataTables scrolling element

Default Value:
  null